Cerberus-KIND
=================

Help to select a schema by "kind" key on cerberus.

Installation
==============

$ pip install cerberus-kind


How To Use
==============

Visit : https://github.com/onetop21/cerberus-kind